package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.GatewayOperationLogMapper;
import com.ruoyi.system.domain.GatewayOperationLog;
import com.ruoyi.system.service.IGatewayOperationLogService;

/**
 * 网关操作日志Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-07-10
 */
@Service
public class GatewayOperationLogServiceImpl implements IGatewayOperationLogService 
{
    @Autowired
    private GatewayOperationLogMapper gatewayOperationLogMapper;

    /**
     * 查询网关操作日志
     * 
     * @param id 网关操作日志主键
     * @return 网关操作日志
     */
    @Override
    public GatewayOperationLog selectGatewayOperationLogById(Long id)
    {
        return gatewayOperationLogMapper.selectGatewayOperationLogById(id);
    }

    /**
     * 查询网关操作日志列表
     * 
     * @param gatewayOperationLog 网关操作日志
     * @return 网关操作日志
     */
    @Override
    public List<GatewayOperationLog> selectGatewayOperationLogList(GatewayOperationLog gatewayOperationLog)
    {
        return gatewayOperationLogMapper.selectGatewayOperationLogList(gatewayOperationLog);
    }

    /**
     * 新增网关操作日志
     * 
     * @param gatewayOperationLog 网关操作日志
     * @return 结果
     */
    @Override
    public int insertGatewayOperationLog(GatewayOperationLog gatewayOperationLog)
    {
        return gatewayOperationLogMapper.insertGatewayOperationLog(gatewayOperationLog);
    }

    /**
     * 修改网关操作日志
     * 
     * @param gatewayOperationLog 网关操作日志
     * @return 结果
     */
    @Override
    public int updateGatewayOperationLog(GatewayOperationLog gatewayOperationLog)
    {
        return gatewayOperationLogMapper.updateGatewayOperationLog(gatewayOperationLog);
    }

    /**
     * 批量删除网关操作日志
     * 
     * @param ids 需要删除的网关操作日志主键
     * @return 结果
     */
    @Override
    public int deleteGatewayOperationLogByIds(Long[] ids)
    {
        return gatewayOperationLogMapper.deleteGatewayOperationLogByIds(ids);
    }

    /**
     * 删除网关操作日志信息
     * 
     * @param id 网关操作日志主键
     * @return 结果
     */
    @Override
    public int deleteGatewayOperationLogById(Long id)
    {
        return gatewayOperationLogMapper.deleteGatewayOperationLogById(id);
    }
}
