package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.GatewayOperationLog;
import com.ruoyi.system.service.IGatewayOperationLogService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 网关操作日志Controller
 * 
 * @author ruoyi
 * @date 2024-07-10
 */
@RestController
@RequestMapping("/system/log")
public class GatewayOperationLogController extends BaseController
{
    @Autowired
    private IGatewayOperationLogService gatewayOperationLogService;

    /**
     * 查询网关操作日志列表
     */
    // @PreAuthorize("@ss.hasPermi('system:log:list')")
    @GetMapping("/list")
    public TableDataInfo list(GatewayOperationLog gatewayOperationLog)
    {
        startPage();
        List<GatewayOperationLog> list = gatewayOperationLogService.selectGatewayOperationLogList(gatewayOperationLog);
        return getDataTable(list);
    }

    /**
     * 导出网关操作日志列表
     */
    // @PreAuthorize("@ss.hasPermi('system:log:export')")
    @Log(title = "网关操作日志", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, GatewayOperationLog gatewayOperationLog)
    {
        List<GatewayOperationLog> list = gatewayOperationLogService.selectGatewayOperationLogList(gatewayOperationLog);
        ExcelUtil<GatewayOperationLog> util = new ExcelUtil<GatewayOperationLog>(GatewayOperationLog.class);
        util.exportExcel(response, list, "网关操作日志数据");
    }

    /**
     * 获取网关操作日志详细信息
     */
    // @PreAuthorize("@ss.hasPermi('system:log:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(gatewayOperationLogService.selectGatewayOperationLogById(id));
    }

    /**
     * 新增网关操作日志
     */
    // @PreAuthorize("@ss.hasPermi('system:log:add')")
    @Log(title = "网关操作日志", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody GatewayOperationLog gatewayOperationLog)
    {
        return toAjax(gatewayOperationLogService.insertGatewayOperationLog(gatewayOperationLog));
    }

    /**
     * 修改网关操作日志
     */
    // @PreAuthorize("@ss.hasPermi('system:log:edit')")
    @Log(title = "网关操作日志", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody GatewayOperationLog gatewayOperationLog)
    {
        return toAjax(gatewayOperationLogService.updateGatewayOperationLog(gatewayOperationLog));
    }

    /**
     * 删除网关操作日志
     */
    // @PreAuthorize("@ss.hasPermi('system:log:remove')")
    @Log(title = "网关操作日志", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(gatewayOperationLogService.deleteGatewayOperationLogByIds(ids));
    }
}
